Enum SamplingValue Copy item path Source pub enum SamplingValue {
SampleRate {
value: f64 ,
},
Factor {
value: f64 ,
},
MinimumSampleRate {
value: f64 ,
},
}Expand description A sampling strategy definition.
A sampling strategy refers to the strategy that we want to use for sampling a specific rule.
A direct sample rate to apply.
A rule with a sample rate will be matched and the final sample rate will be computed by
multiplying its sample rate with the accumulated factors from previous rules.
Fields The sample rate to apply to the rule.
A factor to apply on a subsequently matching rule.
A rule with a factor will be matched and the matching will continue onto the next rules
until a sample rate rule is found. The matched rule’s factor will be multiplied with the
accumulated factors before moving onto the next possible match.
Fields The factor to apply on another matched sample rate.
A minimum sample rate.
The sample rate specified in the rule will be used as a minimum over the otherwise used
sample rate.
Only the first matching minimum sample rate will be applied.
Fields The minimum sample rate used to raise the chosen sample rate.
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Deserialize this value from the given Serde deserializer.
Read more Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Serialize this value into the given Serde serializer.
Read more Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Returns the argument unchanged.
Instruments this type with the provided [
Span], returning an
Instrumented wrapper.
Read more Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The alignment of pointer.
The type for initializers.
Initializes a with the given initializer.
Read more Mutably dereferences the given pointer.
Read more Drops the object pointed to by the given pointer.
Read more Create a new
Policy that returns [
Action::Follow] only if
self and
other return
Action::Follow.
Read more Create a new
Policy that returns [
Action::Follow] if either
self or
other returns
Action::Follow.
Read more The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.